# Macros for building HPX code.
def hpx_component_copts(component_name):
    """Shorthand for needed HPX component compile options
        Returns the needed HPX component compile options.
    """
    return ['-DHPX_COMPONENT_NAME=' + component_name, '-DHPX_COMPONENT_STRING=\\"' + component_name + '\\"', '-fPIC', '-DHPX_COMPONENT_EXPORTS', '-DHPX_ENABLE_ASSERT_HANDLER']

def hpx_application_copts():
    """Shorthand for needed HPX application compile options
        Returns the needed HPX application compile options.
    """
    return ["-DHPX_APPLICATION_EXPORTS", "-DHPX_ENABLE_ASSERT_HANDLER"]

def hpx_copts():
    """Shorthand for needed HPX compile options
        Returns the needed HPX compile options.
    """
    return "-std=c++17".replace("  ", " ").replace(hpx_path(), "hpx").replace(boost_path(), "boost").split(" ")

def hpx_link_opts():
    """Shorthand for needed HPX link options
        Returns the needed HPX link options.
    """
    return "-std=c++17 -L/usr/local  -L/usr/local/lib /lib/libhpx_init.a /lib/libhpx.so  -lrt /usr/local/lib/libboost_context.so /usr/local/lib/libboost_thread.so -l-pthread /usr/local/lib/libboost_chrono.so /usr/local/lib/libboost_atomic.so /usr/local/lib/libboost_filesystem.so /usr/local/lib/libboost_program_options.so /usr/local/lib/libboost_regex.so /usr/local/lib/libboost_system.so /usr/local/lib/libboost_date_time.so /usr/lib/libpthread.so /usr/local/lib/libboost_context.so /usr/local/lib/libboost_thread.so -l-pthread /usr/local/lib/libboost_chrono.so /usr/local/lib/libboost_atomic.so /usr/local/lib/libboost_filesystem.so /usr/local/lib/libboost_program_options.so /usr/local/lib/libboost_regex.so /usr/local/lib/libboost_system.so /usr/local/lib/libboost_date_time.so /usr/local/lib/libhwloc.so  ".replace("  ", " ").replace(hpx_path(), "hpx").replace(boost_path(), "boost").split(" ")

def hpx_path():
    """Shorthand for the HPX path
        Returns the HPX path.
    """
    return "/usr/local"

def boost_path():
    """Shorthand for the Boost path
        Returns the Boost path.
    """
    return ""
